pub fn build_bytes(gm_data: &GMData) -> Result<Vec<u8>>Expand description
Builds a GameMaker data file and returns a byte buffer.
If you want to build the data file directly to a file on disk, check out
build_file.
For more information on the data file format, see crate::wad.